@@ -1,7 +1,6 @@
 """
 This module provides classes to specify atomic structure
 """
-# from jarvis.analysis.structure.spacegroup import Spacegroup3D
 from collections import Counter
 import numpy as np
 from jarvis.core.composition import Composition
@@ -12,8 +11,7 @@ from collections import OrderedDict
 import pprint
 import math
 from numpy.linalg import norm, solve
-
-plt.switch_backend("agg")
+from jarvis.core.utils import get_counts
 amu_gm = 1.66054e-24
 ang_cm = 1e-8
 
@@ -30,7 +28,9 @@ class Atoms(object):
         show_props=False,
     ):
         """
+        
         Create atomic structure with lattice, coordinates, atom type and other information
+        
         >>> box = [[2.715, 2.715, 0], [0, 2.715, 2.715], [2.715, 0, 2.715]]
         >>> coords = [[0, 0, 0], [0.25, 0.2, 0.25]]
         >>> elements = ["Si", "Si"]
@@ -59,6 +59,7 @@ class Atoms(object):
         'C2/m (12)'
         >>> Si.pymatgen_converter()!={}
         True
+        
         """
 
         self.lattice_mat = np.array(lattice_mat)
@@ -85,9 +86,13 @@ class Atoms(object):
             Check if the surface structure is polar
             by comparing atom types at top and bottom.
             Applicable for sufcae with vaccums only.
+            
             Args:
+            
                  file:atoms object (surface with vacuum)
+                 
             Returns:
+            
                    polar:True/False   
         """
         up = 0
@@ -163,6 +168,17 @@ class Atoms(object):
             props=new_props,
             cartesian=False,
         )
+    
+    @property
+    def get_primitive_atoms(self):
+        from jarvis.analysis.structure.spacegroup import Spacegroup3D
+        return Spacegroup3D(self).primitive_atoms
+
+    @property
+    def raw_distance_matrix(self):
+        coords = np.array(self.cart_coords)
+        z = (coords[:, None, :] - coords[None, :, :]) ** 2
+        return np.sum(z, axis=-1) ** 0.5
 
     def center(self, axis=2, vacuum=18.0, about=None):
         """
@@ -239,7 +255,7 @@ class Atoms(object):
         comp = {}
         for i in self.elements:
             comp[i] = comp.setdefault(i, 0) + 1
-        return Composition(comp)
+        return Composition(OrderedDict(comp))
 
     @property
     def density(self):
@@ -522,17 +538,19 @@ class Atoms(object):
         )
         order = np.argsort(self.elements)
         coords = self.frac_coords
+
         coords_ordered = np.array(coords)[order]
         elements_ordered = np.array(self.elements)[order]
         props_ordered = np.array(self.props)[order]
+        counts = get_counts(elements_ordered)
+
         middle = (
-            " ".join(map(str, Counter(elements_ordered).keys()))
+            " ".join(map(str, counts.keys()))
             + "\n"
-            + " ".join(map(str, Counter(elements_ordered).values()))
+            + " ".join(map(str, counts.values()))
             + "\ndirect\n"
         )
         rest = ""
-        # print ('repr',self.frac_coords, self.frac_coords.shape)
         for ii, i in enumerate(coords_ordered):
 
             if self.show_props == True:
@@ -591,29 +609,28 @@ class Atoms(object):
         )
         order = np.argsort(self.elements)
         coords = self.frac_coords
-        coords_ordered = np.array(coords)[order]
-        elements_ordered = np.array(self.elements)[order]
-        props_ordered = np.array(self.props)[order]
+        coords_ordered = np.array(coords)#[order]
+        elements_ordered = np.array(self.elements)#[order]
+        props_ordered = np.array(self.props)#[order]
         check_selective_dynamics = False
+        counts = get_counts(elements_ordered)
         if "T" in "".join(map(str, self.props[0])):
             middle = (
-                " ".join(map(str, Counter(elements_ordered).keys()))
+                " ".join(map(str, counts.keys()))
                 + "\n"
-                + " ".join(map(str, Counter(elements_ordered).values()))
+                + " ".join(map(str, counts.values()))
                 + "\nSelective dynamics\n"
                 + "Direct\n"
             )
         else:
             middle = (
-                " ".join(map(str, Counter(elements_ordered).keys()))
+                " ".join(map(str, counts.keys()))
                 + "\n"
-                + " ".join(map(str, Counter(elements_ordered).values()))
+                + " ".join(map(str, counts.values()))
                 + "\ndirect\n"
             )
         rest = ""
 
-        # print ('props_ordered',props_ordered)
-        # print ('repr',self.frac_coords, self.frac_coords.shape)
         for ii, i in enumerate(coords_ordered):
             if self.show_props == True:
                 rest = (
@@ -786,13 +803,18 @@ class VacuumPadding(object):
         )
         return with_vacuum_atoms
 
+
+
+
 """
 if __name__ == "__main__":
     box = [[2.715, 2.715, 0], [0, 2.715, 2.715], [2.715, 0, 2.715]]
     coords = [[0, 0, 0], [0.25, 0.25, 0.25]]
     elements = ["Si", "Si"]
     Si = Atoms(lattice_mat=box, coords=coords, elements=elements)
-    print (Si.get_string())
+    #print (Si.get_string())
+    print (Si.get_primitive_atoms)
+    print (Si.raw_distance_matrix)
     import sys
     sys.exit()
     #print (Si.props)
