@@ -9,13 +9,17 @@ import numpy as np
 from jarvis.core.atoms import Atoms
 from collections import OrderedDict
 from jarvis.core.kpoints import generate_kgrid, Kpoints3D
+from jarvis.core.utils import get_counts
 
 
 class Poscar(object):
     """
     Class defining Poscar object 
+
     Args:
+    
         atoms : Atoms object
+        
         comment : Header of Poscar file
     """
 
@@ -32,6 +36,10 @@ class Poscar(object):
             return Poscar.from_string(f.read())
 
     def write_file(self, filename):
+        """
+        Write the Poscar object to a file
+        """
+        
         f = open(filename, "w")
         header = (
             str(self.comment)
@@ -57,23 +65,24 @@ class Poscar(object):
         )
         order = np.argsort(self.atoms.elements)
         coords = self.atoms.frac_coords
-        coords_ordered = np.array(coords)[order]
-        elements_ordered = np.array(self.atoms.elements)[order]
-        props_ordered = np.array(self.atoms.props)[order]
+        coords_ordered = np.array(coords)#[order]
+        elements_ordered = np.array(self.atoms.elements)#[order]
+        props_ordered = np.array(self.atoms.props)#[order]
         check_selective_dynamics = False
+        counts = get_counts(elements_ordered)
         if "T" in "".join(map(str, self.atoms.props[0])):
             middle = (
-                " ".join(map(str, Counter(elements_ordered).keys()))
+                " ".join(map(str, counts.keys()))
                 + "\n"
-                + " ".join(map(str, Counter(elements_ordered).values()))
+                + " ".join(map(str, counts.values()))
                 + "\nSelective dynamics\n"
                 + "Direct\n"
             )
         else:
             middle = (
-                " ".join(map(str, Counter(elements_ordered).keys()))
+                " ".join(map(str, counts.keys()))
                 + "\n"
-                + " ".join(map(str, Counter(elements_ordered).values()))
+                + " ".join(map(str, counts.values()))
                 + "\ndirect\n"
             )
         rest = ""
@@ -88,6 +97,10 @@ class Poscar(object):
 
     @staticmethod
     def from_string(lines):
+        """
+        Read Poscar from strings, useful in reading files/streams
+        """
+        
         text = lines.splitlines()
         comment = text[0]
         scale = float(text[1])
@@ -152,19 +165,20 @@ class Poscar(object):
         elements_ordered = np.array(self.atoms.elements)[order]
         props_ordered = np.array(self.atoms.props)[order]
         check_selective_dynamics = False
+        counts = get_counts(elements_ordered)
         if "T" in "".join(map(str, self.atoms.props[0])):
             middle = (
-                " ".join(map(str, Counter(elements_ordered).keys()))
+                " ".join(map(str, counts.keys()))
                 + "\n"
-                + " ".join(map(str, Counter(elements_ordered).values()))
+                + " ".join(map(str, counts.values()))
                 + "\nSelective dynamics\n"
                 + "Direct\n"
             )
         else:
             middle = (
-                " ".join(map(str, Counter(elements_ordered).keys()))
+                " ".join(map(str, counts.keys()))
                 + "\n"
-                + " ".join(map(str, Counter(elements_ordered).values()))
+                + " ".join(map(str, counts.values()))
                 + "\ndirect\n"
             )
         rest = ""
@@ -177,7 +191,7 @@ class Poscar(object):
 
 class Incar(object):
     """
-    VASP INCAR files as python dictionary
+    VASP INCAR files as python dictionary of keys and values
     """
 
     def __init__(self, tags={}):
@@ -185,11 +199,19 @@ class Incar(object):
 
     @staticmethod
     def from_file(filename="INCAR"):
+        """
+        Read INCAR file
+        """
+        
         with open(filename, "r") as f:
             return Incar.from_string(f.read())
 
     def update(self, d={}):
-        print("selftags1=", self._tags)
+        """
+        Provide the new tags as a dictionary to update Incar object
+        """
+        
+        #print("selftags1=", self._tags)
         if self._tags != {}:
             for i, j in self._tags.items():
                 self._tags[i] = j  # .strip(' ')
@@ -199,6 +221,10 @@ class Incar(object):
         return Incar(self._tags)
 
     def get(self, key="POTIM", temp=0.5):
+        """
+        Get the value of a key
+        """
+        
         if key in list(self._tags.keys()):
             return self._tags[key]
         else:
@@ -207,10 +233,13 @@ class Incar(object):
             return self._tags[key]
 
     def to_dict(self):
+        """
+        Convert into dictionary
+        """
+        
         return self._tags
 
     def from_dict(self, data={}):
-        print("data", data)
         return Incar(tags=data)
 
     @staticmethod
@@ -228,6 +257,10 @@ class Incar(object):
         return str(self._tags)
 
     def write_file(self, filename):
+        """
+        Write Incar to a file
+        """
+        
         tags = self._tags
         lines = ""
         for i, j in tags.items():
@@ -246,6 +279,10 @@ class IndividualPotcarData(object):
         self._data = data
 
     def from_string(lines):
+        """
+        Some of the contents in the POTCAR
+        """
+        
         text = lines.splitlines()
         individual_data = OrderedDict()
         individual_data["header1"] = text[0]
@@ -359,7 +396,11 @@ class Kpoints(object):
             ValueError("K-point scheme is not implemented")
 
     def get_mesh_kp(lines=""):
-        print("lines", lines)
+        #print("lines", lines)
+        """
+        Read Kpoints as grid
+        """
+        
         grid = [int(i) for i in lines[3].split()]
         # print (grid)
         kpts = generate_kgrid(grid)
@@ -367,6 +408,10 @@ class Kpoints(object):
         return kpoints
 
     def get_ibz_kp(lines=""):
+        """
+        Read the Kpoints in the line-mode
+        """
+        
         kp_labels = []
         all_kp = []
         kp_labels_points = []
